/**
 * @copyright 2021 Double Bastion LLC <www.doublebastion.com>
 *
 * @author Double Bastion LLC
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU AFFERO GENERAL PUBLIC LICENSE
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU AFFERO GENERAL PUBLIC LICENSE for more details.
 *
 * You should have received a copy of the GNU Affero General Public
 * License along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#app {
  position: relative;
  display: flex;
  min-height: 100%;
  min-width: 100%;
}

#app-content {
   position: relative;
   z-index: 1000;
   flex-basis: 100vw;
   min-width: 0;
   min-height: 100%;
   margin: 0 !important;
   overflow-y: scroll;
}

#app-content #app-content-wrapper {
   height: 100%;
}

.sip_trip_box {
  width: 400px;
  display: block;
}

#settings-dscr {
  padding-top: 3px;
}

#sip_trip_phone_save_msg {
  color: #181918;
  background-color: #a5e5b3;
  font-weight: bold;
}

#STPhoneContent {
  display: block; 
  position: relative;
  width: 100%;
  height: 100%;
}

#STPhoneGreyLogo {
  display: block;
  margin-top: -40px;
  position: relative;
  background-image: url('../img/sip_trip_phone_grey.svg');
  background-repeat: no-repeat;
  background-position: center center;
  width: 100%;
  height: 100%;
}

#labelSipRealm {
  width: 400px;
}